@@ -605,9 +605,7 @@ get_glyph_items_in_range (HTMLTextSlave *slave, HTMLPainter *painter, int start_
 				tmp_gi = pango_glyph_item_split (&glyph_item->glyph_item, slave->owner->text, split_index);
 
 				/* free the beginning we don't need */
-				pango_item_free (tmp_gi->item);
-				pango_glyph_string_free (tmp_gi->glyphs);
-				g_free (tmp_gi);
+				pango_glyph_item_free (tmp_gi);
 				
 			}
 
@@ -627,11 +625,13 @@ get_glyph_items_in_range (HTMLTextSlave *slave, HTMLPainter *painter, int start_
 				tmp_gi2 = pango_glyph_item_split (&tmp_gi1, slave->owner->text, split_index);
 
 				glyph_item->glyph_item = *tmp_gi2;
+				tmp_gi2->item = NULL;
+				tmp_gi2->glyphs = NULL;
 
 				/* free the tmp1 content and tmp2 container, but not the content */
 				pango_item_free (tmp_gi1.item);
 				pango_glyph_string_free (tmp_gi1.glyphs);
-				g_free (tmp_gi2);
+				pango_glyph_item_free (tmp_gi2);
 
 				glyph_item->type = HTML_TEXT_SLAVE_GLYPH_ITEM_CREATED;
 				glyph_item->widths = NULL;
@@ -1052,15 +1052,6 @@ check_point (HTMLObject *self,
 	return NULL;
 }
 
-static void
-clear_glyphs (HTMLTextSlave *slave)
-{
-	if (slave->glyphs) {
-		glyphs_destroy (slave->glyphs);
-		slave->glyphs = NULL;
-	}
-}
-
 static void
 clear_glyph_items (HTMLTextSlave *slave)
 {
@@ -1075,7 +1066,6 @@ destroy (HTMLObject *obj)
 {
 	HTMLTextSlave *slave = HTML_TEXT_SLAVE (obj);
 
-	clear_glyphs (slave);
 	clear_glyph_items (slave);
 
 	HTML_OBJECT_CLASS (parent_class)->destroy (obj);
@@ -1136,7 +1126,6 @@ html_text_slave_init (HTMLTextSlave *slave,
 	slave->owner      = owner;
 	slave->charStart  = NULL;
 	slave->pi         = NULL;
-	slave->glyphs     = NULL;
 	slave->glyph_items = NULL;
 
 	/* text slaves have always min_width 0 */
@@ -1186,6 +1175,8 @@ html_text_slave_get_glyph_item_at_offset (HTMLTextSlave *slave, HTMLPainter *pai
 	GSList *cur;
 	int index;
 
+	prev_gi = next_gi = NULL;
+
 	index = g_utf8_offset_to_pointer (html_text_slave_get_text (slave), offset) - slave->owner->text;
 	if (index_out)
 		*index_out = index;
